@@ -133,7 +133,7 @@ rip_out_paths( const Environments &envs, map<string, string> &version_map, map<s
 
     Environments env2;
 
-    static const char *suffs[] = { ".tar.bz2", ".tar.gz", ".tar" };
+    static const char *suffs[] = { ".tar.bz2", ".tar.gz", ".tar", ".tgz" };
 
     string versfile;
 
