@@ -320,9 +320,9 @@ MsgChannel::operator>> (uint32_t &buf)
   if (inofs >= intogo + 4)
     {
       if ( ptrdiff_t(inbuf + intogo) % 4 ) {
-        char t_buf[4];
+        uint32_t t_buf[1];
         memcpy(t_buf, inbuf + intogo, 4);
-        buf = *(uint32_t *)t_buf;
+        buf = t_buf[0];
       } else
         buf = *(uint32_t *)(inbuf + intogo);
       intogo += 4;
@@ -850,11 +850,16 @@ MsgChannel::wait_for_msg (int timeout)
 {
   if (has_msg ())
     return true;
-  if (!read_a_bit () || timeout <= 0)
+  if (!read_a_bit ())
     {
-      trace() << "!read_a_bit || timeout <= 0\n";
+      trace() << "!read_a_bit\n";
       return false;
     }
+  if (timeout <= 0)
+    {
+      trace() << "timeout <= 0\n";
+      return has_msg ();
+    }
   while (!has_msg ())
     {
       fd_set read_set;
@@ -884,8 +889,8 @@ MsgChannel::get_msg(int timeout)
   Msg *m = 0;
   enum MsgType type;
   uint32_t t;
-  if (timeout > 0 && !wait_for_msg (timeout) ) {
-    trace() << "blocking && !waiting_for_msg()\n";
+  if (!wait_for_msg (timeout) ) {
+    trace() << "!wait_for_msg()\n";
     return 0;
   }
   /* If we've seen the EOF, and we don't have a complete message,
